ProviderAuthStatus

Enum ProviderAuthStatus 

pub enum ProviderAuthStatus {
    Configured {
        format_valid: bool,
    },
    EnvVar {
        var_name: String,
    },
    OAuth,
    Missing,
}
The authentication status of a provider.

Variants



Configured

API key is configured and has a recognized format.

Fields

format_valid: bool

Whether the key format looks valid.



EnvVar

Auth is configured via environment variable reference.

Fields

var_name: String

The environment variable name (e.g., “ANTHROPIC_API_KEY”).



OAuth

OAuth token is configured.



Missing

No authentication is configured for this provider.

Implementations

Source

impl ProviderAuthStatus

pub fn from_provider(provider_id: &str, auth_entry: Option<&AuthEntry>) -> Self

Check the auth status for a given provider based on its auth entry and provider configuration.

pub fn from_env_var(provider_id: &str) -> Self

Check auth status using env var fallback.