pub fn read_config<T: DeserializeOwned>(path: &Path) -> Result<T>Expand description
Read a config file and deserialize into the target type.
Supports both JSON and JSONC files.
pub fn read_config<T: DeserializeOwned>(path: &Path) -> Result<T>Read a config file and deserialize into the target type.
Supports both JSON and JSONC files.