pub enum ProviderAuthStatus {
Configured {
format_valid: bool,
},
EnvVar {
var_name: String,
},
OAuth,
Missing,
}Expand description
The authentication status of a provider.
Variants
Configured
API key is configured and has a recognized format.
EnvVar
Auth is configured via environment variable reference.
OAuth
OAuth token is configured.
Missing
No authentication is configured for this provider.
Implementations
Sourceimpl ProviderAuthStatus
impl ProviderAuthStatus
Sourcepub fn from_provider(provider_id: &str, auth_entry: Option<&AuthEntry>) -> Self
pub fn from_provider(provider_id: &str, auth_entry: Option<&AuthEntry>) -> Self
Check the auth status for a given provider based on its auth entry and provider configuration.
Sourcepub fn from_env_var(provider_id: &str) -> Self
pub fn from_env_var(provider_id: &str) -> Self
Check auth status using env var fallback.